@@ -7,7 +7,7 @@
 ;; Package-Requires: ((emacs "28.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/DevelopmentCool2449/colorful-mode
 ;; Keywords: faces, tools, matching, convenience
-;; Version: 1.0.3
+;; Version: 1.0.4
 
 ;; This file is part of GNU Emacs.
 
@@ -277,15 +277,6 @@ If set to only-prog, only highlight colors in strings if current major
 mode is derived from `prog-mode'."
   :type '(choice boolean (const :tag "Only in prog-modes" only-prog)))
 
-
-;;;; Keymaps
-
-(defvar-keymap colorful-mode-map
-  :doc "Keymap for `colorful-mode'."
-  "C-x c x" #'colorful-change-or-copy-color
-  "C-x c c" #'colorful-convert-and-copy-color
-  "C-x c r" #'colorful-convert-and-change-color)
-
 
 ;;;; Internal variables
 
@@ -750,6 +741,14 @@ This is intended to be used with `colorful-extra-color-keyword-functions'."
   (font-lock-remove-keywords nil `(,@colorful-color-keywords))
   (remove-overlays nil nil 'colorful--overlay t))
 
+;;;; Keymap
+
+(defvar-keymap colorful-mode-map
+  :doc "Keymap for `colorful-mode'."
+  "C-x c x" #'colorful-change-or-copy-color
+  "C-x c c" #'colorful-convert-and-copy-color
+  "C-x c r" #'colorful-convert-and-change-color)
+
 ;;;###autoload
 (define-minor-mode colorful-mode
   "Preview any color in your buffer such as hex, color names, CSS rgb in real time."
@@ -765,9 +764,15 @@ This is intended to be used with `colorful-extra-color-keyword-functions'."
 ;; patch.
 (defvar global-colorful-modes)
 
+;;;###autoload
+(defun turn-on-colorful-mode ()
+  "Turn on `colorful-mode' mode if the current buffer."
+  (unless colorful-mode
+    (colorful-mode t)))
+
 ;;;###autoload
 (define-globalized-minor-mode global-colorful-mode
-  colorful-mode colorful--turn-on
+  colorful-mode turn-on-colorful-mode
   :predicate '(mhtml-mode html-ts-mode latex-mode prog-mode))
 
 
